@@ -1,16 +1,8 @@
 /*
- *
- * Copyright (C) 2003-2008 Sebastian Trueg <trueg@k3b.org>
- *
- * This file is part of the K3b project.
- * Copyright (C) 1998-2008 Sebastian Trueg <trueg@k3b.org>
- *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- * See the file "COPYING" for the exact licensing terms.
- */
+    SPDX-FileCopyrightText: 1998-2008 Sebastian Trueg <trueg@k3b.org>
+
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 
 #ifndef K3BDATADIRTREEVIEW_H
@@ -38,7 +30,7 @@ namespace K3b {
 
     public:
         DataDirTreeView( View*, DataDoc*, QWidget* parent );
-        virtual ~DataDirTreeView();
+        ~DataDirTreeView() override;
 
         /**
          * \return The item at position \p pos (local coordinates)
